;-----------------------------------------------------------------------------------------------------------------------------------------------------UPDATE: 16-12-2020-------
;---------------------------------------------Carlos de Matos Fernandes--------------------------------------------------------------------------------------------------------
;---------------------------------------------ABM on Bad Barrels spoiling good apples------------------------------------------------------------------------------------------
;------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

extensions [ nw ]                                          ;; network extension needed

globals [
  sorted-groups                                            ;; preference list of groups available. Ordered based on average level of cooperation in the group.
  moody-segregation                                        ;; MS index to calculate the chances for a same-type tie in the social network
  prosociality-segregation                                 ;; MS index to calcualte the chances for a same-type tie in the group context
  my-seed                                                  ;; seed of the run (random)
]

undirected-link-breed [ studyties studytie ]               ;; study ties for the group
undirected-link-breed [ socialties socialtie ]             ;; social ties for the social network

breed [ students student ]                                 ;; turtles defined as students
breed [ groups group ]                                     ;; turtles defined as overarching group

groups-own [
  group-label                                              ;; label of the group
  average-group                                            ;; average level of cooperation, range is 0 (all D) to 1 (all C)
  average-group-history                                    ;; history of level of C in group
  average-group-rate-lastXrounds                           ;; last X rounds
  count-members                                            ;; how many students are part of the study group
]

students-own [
  ;; N-person PD variables
  initial-threshold                                        ;; which type one is
  cooperate?                                               ;; if one cooperate?
  netshare                                                 ;; share received of the public good (benefit - cost)
  threshold                                                ;; updated initial threshold
  my-group                                                 ;; in which group one resides
  coop-history                                             ;; history of cooperation decisions
  decided?                                                 ;; did someone decided to cooperate or defect (1) or not (0) in the PGG
  coop-rate                                                ;; average cooperation rate over the last X iterations
  coop-rate-total                                          ;; average cooperation rate over all iterations
  group-reputation                                         ;; average level of cooperation in one's groups

  ;; 2-person PD variables
  pro-decided?                                             ;; did someone decided to cooperate or defect (1) or not (0) in the social network dyad game
  private-threshold                                        ;; updating private threshold in 2-PD
  private-c?                                               ;; to cooperate or not
  private-netshare                                         ;; net share of 2-person PD (benefit - cost)
  list-private-reputation                                  ;; list of private cooperation decisions, input for private reputation
  private-reputation                                       ;; average level of C with friends from the last X iterations

  ;; meritocratic matching parameters
  pool?                                                    ;; students who were part of the pool (true/false)
  cooperativeness-score-all                                ;; if an agent is part of the re-assembling proces, this variable stores social network cooperativeness and previous group success
  number-of-group-members                                  ;; counting how many group members one has
  input-matching                                           ;; needed to seperate students who have social network information from students who don't have SN info (only group success is then available)
  input-leave-stay                                          ;; individual decision to stay or leave the group

  ;; social network parameter
  temp-prob                                                ;; needed for the network to calculate distance to potential partners on the grid
]

;---------------------------------------SETUP--------------------------------------------------SETUP---------------------------------------------------------------------------
;---------------------------------------------Generating world, network, sorting, and preparing other agent features-----------------------------------------------------------
to setup                                ;; setting up the torus
  ca
  set my-seed random 10000000                                                                               ;; set seed
  set-default-shape students "face happy"                                                                   ;; students have a happy face
  make-world-at-random                                                                                      ;; create students and groups
  setup-initial-threshold                                                                                   ;; provide each agent with a threshold
  ;set behavioral-homophily? ifelse-value selection? = "matching-rule-6" [ true ] [ false ]                  ;; allow homophily when matching rule 6 is implemented
  set structural-homophily? ifelse-value selection? = "matching-rule-6" [ true ] [ false ]                  ;; allow homophily when matching rule 6 is implemented
  sort-random                                                                                               ;; sort students at random in the world for random graph algorithm
  if selection? = "matching-rule-5" or selection? = "matching-rule-6" [ generate-random-social-network ]    ;; generate spatial random graph (social network)
  if selection? = "matching-rule-1" [ exogenous-sorting ]                                                   ;; override random initial grouping when matching rule 1 is implemented: grouping based on unilateral cooperation
  create-studytie-group                                                                                     ;; create the studytie groups
  if selection? = "matching-rule-5" or selection? = "matching-rule-6" [
    measure-SN-MS                                                                                           ;; measure odds-ratio for same-type relations
    color-socialties ]                                                                                      ;; color ties based on social network cooperation decision
  measure-prosociality-group                                                                                ;; measure the MS index for prosociality in the group
  if selection? = "matching-rule-1" or selection? = "matching-rule-2" or
    selection? = "matching-rule-3" or selection? = "matching-rule-4" [ sort-circle ]                        ;; form a circle to clearly differentiate between the groups
  reset-ticks
end


to make-world-at-random                 ;; generate students and groups based on globals
  foreach range num-of-groups [                                                            ;; count groups
    group-number -> create-students num-of-agents-per-group [ set label group-number ] ]   ;; sprout count students per group
  foreach range num-of-groups [ g-n -> create-groups 1 [ set label g-n ] ]                 ;; sprout count groups
  ask groups [
    set group-label label                                                                  ;; set label togroup
    set shape "pentagon"                                                                   ;; set shape of the group
    set size 2                                                                             ;; adjust size
    set color cyan                                                                         ;; adjust coloring
    set average-group-history [] ]                                                         ;; set history for group cooperation levels per round
  ask students [
    set my-group label                                                                     ;; set label to my group
    set coop-history []                                                                    ;; set history of each student
    set list-private-reputation []                                                         ;; set list for private cooperative actions
    set input-matching -1                                                                  ;; set a parameter to input variable for matching
  ]
end

to setup-initial-threshold              ;; distribute thresholds
  ask n-of ( round ( %-prosocials * count students ) ) students
  [ set initial-threshold initial-prosocial ]                                              ;; set % of students with prosocial threshold
  ask students with [ initial-threshold != initial-prosocial ]
  [ set initial-threshold initial-proself ]                                                ;; others have proself threshold
  ask students [
    ifelse initial-threshold = initial-prosocial
    [ set color grey + 2 ] [ set color grey - 2 ]                                          ;; adjust coloring for prosocials and proselfs
    set decided? false                                                                     ;; did not decide to C in the group
    set pool? false                                                                        ;; not in the pool for matching
    set pro-decided? false                                                                 ;; did not decide to C in the network
    set threshold initial-threshold                                                        ;; set initial threshold as input for the adaptive threshold
    set private-threshold initial-threshold ]                                              ;; set 2-person PD threhold in network
  if selection? = "matching-rule-1" [
    ask students [
      start-c                                                                              ;; for matching rule 1: unilateral cooperation decision
      set coop-history fput cooperate? coop-history                                        ;; store cooperation decision
      set color ifelse-value ( cooperate? = 1 )                                            ;; coloring of cooperation or defection decision in the group
      [ ifelse-value ( initial-threshold = initial-prosocial ) [ green ] [ green + 3 ] ]
      [ ifelse-value ( initial-threshold = initial-prosocial ) [ red ] [ red + 3 ] ] ] ]
  if selection? = "matching-rule-5" or selection? = "matching-rule-6" [
    ask students [
      let private-prob-to-c ( 1 - private-threshold )                                      ;; calucalte probability to cooperate/defect in the network
      set private-c? ifelse-value ( random-float 1 <= private-prob-to-c  ) [ 1 ] [ 0 ]     ;; decide to C/D in the network
      set list-private-reputation fput private-c? list-private-reputation                  ;; put decision in list
      set private-reputation mean list-private-reputation ] ]                              ;; calculate the mean of that list
end

to sort-random                          ;; social network creation (fixed social network)
  ifelse structural-homophily? = true                                ;; Alter the random placing for homophily
  [ ask students with [ initial-threshold = initial-prosocial ] [    ;; only prosocials are included
      ifelse %-prosocials < 0.4                                      ;; When there are 20% prosocials, sort in the lower left quadrant
      [ setxy random-float min-pxcor random-float min-pycor  ]       ;; random sorting in lower left area
      [ setxy random-xcor random-float min-pycor ] ]                 ;; random sorting in lower half of the grid when there are more than 20% prosocials
    ask students with [ initial-threshold = initial-proself ] [      ;; Proselfs still assort randomly on the grid with homophily implemented
      setxy random-xcor random-ycor ] ]                              ;; Proselfs have the whole grid for random placing
  [ ask students [ setxy random-xcor random-ycor ] ]                 ;; When matching rule 5 is implemented, all are randomly plced on the grid
  ask groups [ hide-turtle ]                                         ;; no group shape visible when social network is implemented
end

to generate-random-social-network       ;; spatial random graph algorithm
  ;; Copied under license GPL-3.0 from: André Grow, Andreas Flache, Rafael Wittek (2017, October 25).
  ;;   “A Model of Global Diversity and Local Consensus in Status Beliefs” (Version 1.2.0).
  ;;   CoMSES Computational Model Library. Retrieved from: https://www.comses.net/codebases/5493/releases/1.2.0/
  ;; Minor adjustments were made, namely: inserting 'student(s)', 'socialtie-neighbor?', and 'create-socialtie-with' instead of
  ;;  'turtle(s)', 'link-neighbor?', and 'create-link-with'.
  ask students [
    let ego who                                                                                   ;; auxiliary variable that indicates the focal actor
    let tie_count 0                                                                               ;; auxiliary variable that tracks how many ties the actor has already established
    while [ tie_count < k ]                                                                       ;; if the actor has not yet established k ties yet, determine who is still available for creating a tie and then
    [ let set_potential_interactors students with [ ( socialtie-neighbor? student ego = FALSE )   ;;   loop through the alternatives and select one of them with a probability that is proportional to the spatial
         and ( who != [ who ] of student ego ) ]                                                  ;;   distance to the focal actor
      if count set_potential_interactors > 0
      [ ask set_potential_interactors [ set temp-prob exp ( - 1 * y * distance student ego) ]
        let alter nobody
        let pick random-float ( sum [ temp-prob ] of set_potential_interactors )
        let comp_low 0
        let comp_high 0
        ask set_potential_interactors
        [ if alter = nobody
          [ set comp_high comp_high + temp-prob
            ifelse pick >= comp_low and pick < comp_high
            [ set alter who ]
            [ set comp_low comp_high ] ] ]
        ask student alter [create-socialtie-with student ego]
        set tie_count tie_count + 1 ] ] ]
end

to exogenous-sorting                    ;; match students who cooperated in the pre-game
  ask students [
    set my-group ""                                                                                   ;; override random-grouping
    set label "" ]
  let unassigned-t students with [ my-group = "" ]                                                    ;; prepare student-set for loop
  let current-t 0                                                                                     ;; counter of the group
  while [ any? unassigned-t ] [                                                                       ;; loop to assign all students to groups
    ask max-n-of num-of-agents-per-group unassigned-t [ cooperate? ] [ set my-group current-t ]       ;; group cooperators together
    set current-t current-t + 1                                                                       ;; on to the next group
    set unassigned-t unassigned-t with [ my-group = "" ] ]                                            ;; update student-set with only ungrouped students
  ask students with [ my-group != "" ] [ set label my-group ]
end

to create-studytie-group                ;; create studyties between students who share labels
  foreach range num-of-groups [ lab -> ask students with [ label = lab ]
    [ create-studyties-with other students with [ label = lab ] ] ]         ;; allow students with the the same labels to form a group
  ask studyties [                                                           ;; color studyties
    set color cyan
    set thickness 0 ]
end

to measure-SN-MS                        ;; social network gross-segregation indicator: odds-ratio of same-type tie in the network
  set moody-segregation
    ( ( ( count socialties with [ [ initial-threshold = initial-prosocial ] of end1 and [ initial-threshold = initial-prosocial ] of end2 ] )        ;; count same-type ties in network
      + ( count socialties with [ [ initial-threshold = initial-proself ] of end1 and [ initial-threshold = initial-proself ] of end2 ] ) )
    * ( ( count students with [ initial-threshold = initial-proself ] * ( count students with [ initial-threshold = initial-prosocial ] - 1 ) )      ;; multiplied by all possible other-type ties in the network
      + ( count students with [ initial-threshold = initial-prosocial ] * ( count students with [ initial-threshold = initial-proself ] - 1 ) ) ) )
   /                                                                                                                                                 ;; divided by
    ( ( ( count socialties with [ [ initial-threshold = initial-prosocial ] of end1 and [ initial-threshold = initial-proself ] of end2 ] )          ;; count other-type ties in network
      + ( count socialties with [ [ initial-threshold = initial-proself ] of end1 and [ initial-threshold = initial-prosocial ] of end2 ] ) )
    * ( ( count students with [ initial-threshold = initial-proself ] * ( count students with [ initial-threshold = initial-proself ] - 1 ) )        ;; multiplied by all possible same-type ties in the network
      + ( count students with [ initial-threshold = initial-prosocial ] * ( count students with [ initial-threshold = initial-prosocial ] - 1 ) ) ) )
end

to measure-prosociality-group           ;; odds-ratio for same-type tie in the group. Also, to accomodate full segregation, we altered the MS index. See the calculation of s3 and the restrictions added
  let s1 ( ( count studyties with [ [ initial-threshold = initial-prosocial ] of end1 and [ initial-threshold = initial-prosocial ] of end2 ] )      ;; count same-type in-group ties
    + ( count studyties with [ [ initial-threshold = initial-proself ] of end1 and [ initial-threshold = initial-proself ] of end2 ] ) )
  let s2 ( ( count students with [ initial-threshold = initial-proself ] * ( count students with [ initial-threshold = initial-prosocial ] - 1 ) )   ;; all possible other-type group ties
    + ( count students with [ initial-threshold = initial-prosocial ] * ( count students with [ initial-threshold = initial-proself ] - 1 ) ) )
  let s3 ( ( count studyties with [ [ initial-threshold = initial-prosocial ] of end1 and [ initial-threshold = initial-proself ] of end2 ] )        ;; count of other-type in-group ties
    + ( count studyties with [ [ initial-threshold = initial-proself ] of end1 and [ initial-threshold = initial-prosocial ] of end2 ] ) )
  let s4 ( ( count students with [ initial-threshold = initial-proself ] * ( count students with [ initial-threshold = initial-proself ] - 1 ) )     ;; all possible same-type in-group ties
    + ( count students with [ initial-threshold = initial-prosocial ] * ( count students with [ initial-threshold = initial-prosocial ] - 1 ) ) )
  if s3 = 0 [ set s3 1]                                                                                                                              ;; when full segregation arise, we allow the MS index to be measured (omitted from data analysis)
  set prosociality-segregation ( ( s1 * s2 ) / ( s3 * s4 ) )
end

to sort-circle                          ;; lay-out in circle sorting
  ask students [
    let group-list label
    let current-group students with [ label = group-list ]    ;; group students with the same group label
    layout-circle current-group 1.5                           ;; prepare layout on the grid
    ask current-group [                                       ;; prepare coordinates for a round of groups ("the round table of sir Group-Arthur"
      set xcor xcor + 14 * cos ( label * 18 )
      set ycor ycor + 14 * sin ( label * 18 ) ] ]
  ask groups [
    show-turtle                                               ;; when students are sorted, show the group turtle
    let group-lister label
    let current-grouper groups with [ label = group-lister ]
    layout-circle current-grouper 0
    ask current-grouper [                                     ;; also prepare the group turtle in the circle
      set xcor xcor + 11 * cos ( label * 18 )
      set ycor ycor + 11 * sin ( label * 18 ) ] ]
end


;----------------------------------------------RESET PARAMETERS-----------------------------------------------------------------------------------------------------------------
to initial-setup                        ;; reset all parameters to baseline setting
  ca
  set num-of-groups 20
  set num-of-agents-per-group 8
  set M 5
  set %-prosocials 0.2
  set L 0.5
  set k 5
  set y 8
  set COST 3
  set BENEFIT 4.5
  set BENEFIT-OF-ALL-D -0.5
  set max-number-of-ticks 400
  set length-last-rounds-history 10
  set initial-prosocial 0.3
  set initial-proself 0.7
  set selection? "matching-rule-1"
  set noise 0.01
  set behavioral-homophily? "off"
  set structural-homophily? "off"
  set count-ticks-for-selection 100
  set r 0.05
  set range-SN 2
  setup
  reset-ticks
end


;---------------------------------------GO--------------------------------------------------GO----------------------------------------------------------------------------------
;-----------------------------------------------------------------Engine of the model-------------------------------------------------------------------------------------------
to go                                   ;; start an iteration
  if ticks = max-number-of-ticks [ stop ]                                                                                         ;; end the run after ? ticks

  ;------N-person PD in the group context
  while [ any? students with [ decided? = false ] ] [ repeat count students [ ask one-of students [ decision-algorithm ] ] ]      ;; some can update their decision multiple times until all have decided
  ask students [ learning-algorithm ]                                                                                             ;; generate outcome, update threshold AFTER all have decided

  ;------2-person PD's in social network, random dyads update their private cooperation based on previous behavior of the other
  if selection? = "matching-rule-5" or selection? = "matching-rule-6" [ repeat ( r * ( count students ) ) [
    ask one-of socialties
      [ ifelse behavioral-homophily? = TRUE
        [ if mean [ private-c? ] of both-ends = 1 or (mean [ private-c? ] of both-ends = 0)                                       ;; only ask similar others (Rule 6)
          ;if (mean [ private-c? ] of both-ends = 1) or
          ; ([ private-c? ] of end1 = 1 and [ private-c? ] of end2 = 1)
          [ update-sn-parameters ] ]
        [ update-sn-parameters ] ] ] ]                                                                                            ;; if prosociality homophily is not activated (Rule 5): ask the pair no matter what

  calculate-features                                                                                                              ;; calculate important features every round
  tick                                                                                                                            ;; move to next iteration
  if (ticks = ( 1 * count-ticks-for-selection ) ) or ( ticks = ( 2 * count-ticks-for-selection ) )                                ;; switch groups after all decided to C/D in the collective good and 2-person PD
      or (ticks = ( 3 * count-ticks-for-selection ) )
     [ engage-in-matching                                                                                                         ;; start matching procedure
       measure-prosociality-group ]                                                                                               ;; measure prosociality segregation in the group context
end

;----------------------------------------------ALGORITHMS FOR COOPERATION------------------------------
to decision-algorithm                   ;; n-person PD: calculate odds to cooperate based on threshold and level of cooperation of others in the group
  let participation-rate ( count in-studytie-neighbors with [ cooperate? = 1 ] / count in-studytie-neighbors )      ;; caclulate how many others cooperated previously
  ifelse selection? = "matching-rule-1" and ticks = 0                                                               ;; for matching rule 1 the first decision was unilaterally made, so they information about previous C/D decisions
  [ let prob-c ( 1 / ( 1 + exp ( M * ( threshold - ( participation-rate ) ) ) ) )                                   ;; calculate the probability to cooperate
    set cooperate? ifelse-value ( random-float 1 <= prob-c  ) [ 1 ] [ 0 ] ]                                         ;; use probability to C to decide between cooperation and defection
  [ ifelse ticks = 0 or pool? = true                                                                                ;; for matcing rules 2-6, different procedure
    [ start-c ]                                                                                                     ;; probability to C is solely based on the initial-threshold in the first round
    [ let prob-c ( 1 / ( 1 + exp ( M * ( threshold - ( participation-rate ) ) ) ) )                                 ;; furture rounds: calculate the probability to cooperate
      set cooperate? ifelse-value ( random-float 1 <= prob-c  ) [ 1 ] [ 0 ] ] ]                                     ;; use probability to C to decide between cooperation and defection
  set shape ifelse-value cooperate? = 1 [ "face happy" ] [ "face sad" ]                                             ;; adjust shape accordingly to decision
  set size ifelse-value cooperate? = 1 [ 1.2 ] [ 0.7 ]                                                              ;; adjust size accordingly
  set color ifelse-value ( cooperate? = 1 )                                                                         ;; adjust color accordingly
   [ ifelse-value ( initial-threshold = initial-prosocial ) [ green ] [ green + 3 ] ]
   [ ifelse-value ( initial-threshold = initial-prosocial ) [ red ] [ red + 3 ] ]
  set decided? true                                                                                                 ;; a decision is made, so set true
end

to start-c                              ;; n-person PD: procedure for first round decision in the group
  let prob-c ( 1 - initial-threshold )                                   ;; probability to C is solely based on the initial-threshold
  set cooperate? ifelse-value ( random-float 1 <= prob-c  ) [ 1 ] [ 0 ]  ;; use probability to C to decide between cooperation (1) and defection (0)
end

to learning-algorithm                   ;; n-person PD: updating threshold for the next round, based on netshare and standardized outcome measures
  let old-netshare netshare                                                                                                            ;; store old net payoff
  let how-many-other-c ( count in-studytie-neighbors with [ cooperate? = 1 ] )                                                         ;; how many others cooperated in the group?
  set netshare ifelse-value cooperate? = 1                                                                                             ;; calculate payoff
    [ ( ( BENEFIT + ( how-many-other-c * BENEFIT )) / num-of-agents-per-group ) - COST ]                                               ;; net payoff of cooperator
    [ ifelse-value how-many-other-c = 0 [ BENEFIT-OF-ALL-D ] [ ( ( how-many-other-c * BENEFIT ) / ( num-of-agents-per-group ) ) ] ]    ;; net payoff of defector
  let max-benefit ( ( ( ( num-of-agents-per-group ) - 1 ) * BENEFIT ) / num-of-agents-per-group )                                      ;; if one defects and all others cooperate is the maxixum absolute value of S.
  let outcome ( ( L * ( ( 2 * netshare ) - old-netshare ) ) / ( 3 * max-benefit ) )                                                    ;; outcome measured based on learning rate
  let old-threshold threshold                                                                                                          ;; store old threshold
  let max-outcome ifelse-value outcome = 0 [ 0.00001 ] [ outcome ]                                                                     ;; outcome cannot be zero
  set threshold (old-threshold                                                                                                         ;; update threshold based on outcome
    - ( ( outcome * ( 1 - ( ( 1 - old-threshold ) ^ ( 1 / ( abs max-outcome ) ) ) ) ) * cooperate? )                                   ;; threshold down (up) if outcome of cooperator is positive (negative)
    + ( ( outcome * ( 1 - ( ( 1 - old-threshold ) ^ ( 1 / ( abs max-outcome ) ) ) ) ) * ( 1 - cooperate? ) ) )                         ;; threshold up (down) if outcome of defector is positve (negative)
  if threshold < 0 [ set threshold 0 ]                                                                                                 ;; lower boundary of the threshold
  if threshold > 1 [ set threshold 1 ]                                                                                                 ;; higher boundary of the threshold
  set decided? false                                                                                                                   ;; after decision> set this false for next iteration
  set pool? false                                                                                                                      ;; if pool was true, set false after matching
end

to update-sn-parameters                 ;; 2-person PD: engage in social network decisions
  ask both-ends [ private-decision ]                               ;; social network decision algorithm (which is the same as in the group)
  ask both-ends with [ pro-decided? = true ] [ private-learning ]  ;; update threshold for the next iterations based on the learning algorithm
end

to private-decision                     ;; 2-person PD: calculating odds to privately cooperate/defect with a randomly selected neighbor
  let private-c-other ifelse-value [ private-c? ] of other-end = 1 [ 1 ] [ 0 ]                              ;; did the other previously cooperated in the network
  let private-prob-to-c ( 1 / ( 1 + exp ( M * ( private-threshold - ( private-c-other ) ) ) ) )             ;; calculate probability to cooperate in 2-PD in the network
  set private-c? ifelse-value ( random-float 1 <= private-prob-to-c  ) [ 1 ] [ 0 ]                          ;; use probability to C to decide between cooperation and defection in the network
  set list-private-reputation fput private-c? list-private-reputation                                       ;; put decision in list
  set private-reputation ifelse-value length list-private-reputation >= length-last-rounds-history          ;; if there are more than 10 private decisions only choose last 10
   [ mean sublist list-private-reputation 0 length-last-rounds-history ]                                    ;; true: mean of last 10 decisions
   [ mean list-private-reputation ]                                                                         ;; false: less than 10 decisions, select all decision available
  set pro-decided? true                                                                                     ;; if decision is made in the 2-PD set TRUE
end

to private-learning                     ;; 2-person PD: updating threshold for the next round, based on netshare and standardized outcome measures
  let private-old-netshare private-netshare                                                                                            ;; store old net payoff
  let c-other? ifelse-value [ private-c? ] of other-end = 1 [ 1 ] [ 0 ]                                                                ;; did the other in the network cooperate?
  set private-netshare ifelse-value private-c? = 1                                                                                     ;; calculate payoff
    [ (( BENEFIT + ( c-other? * BENEFIT )) / 2 ) - COST ]                                                                              ;; net payoff of cooperator in the network
    [ ifelse-value c-other? = 0 [ BENEFIT-OF-ALL-D ] [ ( ( c-other? * BENEFIT ) / 2 ) ] ]                                              ;; net payoff of defector in the network
  let private-outcome ( ( L * ( ( 2 * private-netshare ) - private-old-netshare ) ) / ( 3 *  ( BENEFIT / 2  ) ) )                      ;; outcome measured based on learning rate
  let private-old-threshold private-threshold                                                                                          ;; store old threshold
  let private-max-outcome ifelse-value private-outcome = 0 [ 0.00001 ] [ private-outcome ]                                             ;; outcome cannot be zero
  set private-threshold (private-old-threshold                                                                                         ;; update threshold based on outcome
    - ( ( private-outcome * ( 1 - ( ( 1 - private-old-threshold ) ^ ( 1 / ( abs private-max-outcome ) ) ) ) ) * private-c? )           ;; threshold down (up) if outcome of cooperator is positive (negative)
    + ( ( private-outcome * ( 1 - ( ( 1 - private-old-threshold ) ^ ( 1 / ( abs private-max-outcome ) ) ) ) ) * ( 1 - private-c? ) ) ) ;; threshold up (down) if outcome of defector is positve (negative)
  if private-threshold < 0 [ set private-threshold 0 ]                                                                                 ;; lower boundary of the threshold
  if private-threshold > 1 [ set private-threshold 1 ]                                                                                 ;; higher boundary of the threshold
  set pro-decided? false                                                                                                               ;; after decision? set this false for next interaction in the network
end


;-----------------------------------------INDIVIDUAL, TIE AND GROUP FEATURES---------------------------
to calculate-features                   ;; calculate cooperation and group performance rates + coloring of social ties
  foreach range num-of-groups [ ff -> ask groups with [ label = ff ]
    [ set average-group ( count students with [ label = ff and cooperate? = 1 ] / count students with [ label = ff ] ) ] ]  ;; average level of C per group
  ask groups [
    set average-group-history fput average-group average-group-history                                                      ;; store level of C in group
    if ticks > length-last-rounds-history [ set average-group-rate-lastXrounds
      mean sublist average-group-history 0 length-last-rounds-history ] ]                                                   ;; mean C in group per last X rounds
  foreach range num-of-groups [ ff -> ask students with [ label = ff ]
    [ if ticks >= length-last-rounds-history [ set group-reputation
      ( item 0 [ average-group-rate-lastXrounds ] of groups with [ label = ff ] ) ] ] ]                                     ;; set group success as individual feature
  ask students [
    set coop-history fput cooperate? coop-history                                                                           ;; history of behavior of each agent
    set coop-rate-total mean coop-history                                                                                   ;; mean cooperat level per agent
    if ticks > 10 [ set coop-rate mean sublist coop-history 0 length-last-rounds-history ] ]                                ;; calculate history only last X rounds
  set sorted-groups sort-on [ ( - average-group-rate-lastXrounds ) ] groups                                                 ;; generate global of preference list of groups that perform well
  color-socialties                                                                                                          ;; color the social ties according to social network cooperation decisions
end

to color-socialties                     ;; visualize how many dyads are cooperative in 2-person PD
  ask socialties with [ [ private-c? = 1 ] of end1 and [ private-c? = 1 ] of end2 ] [ set color white set thickness 0.3 ]                                 ;; tie = white if both cooperated in the network
  ask socialties with [ ( [private-c? = 0 ] of end1 or [ private-c? = 1 ] of end1) and [ private-c? = 0 ] of end2 ] [ set color red set thickness 0.2 ]   ;; tie = red if both or one defected in the network
  ask socialties with [ [ private-c? = 0 ] of end1 and ( [ private-c? = 0 ] of end2 or [ private-c? = 1 ] of end2 ) ] [ set color red set thickness 0.2 ] ;; tie = red if both or one defected in the network
end


;----------------------------------------------ALGORITHMS FOR meritocratic matching--------------------------
to engage-in-matching                   ;; matching procedure
  ask students [ if selection? = "matching-rule-5" or selection? = "matching-rule-6"
    [ set cooperativeness-score-all ( ( group-reputation + private-reputation ) / 2 ) ] ]       ;; calculate the shared effect of private cooperativeness and group succes
  ask studyties [ die ]                                                                         ;; remove old studyties in order to form studyties to new group members
  switch-groups                                                                                 ;; go to the matching algorithm
  create-studytie-group                                                                         ;; after some agents switched groups, make the new studynetwork
  if selection? = "matching-rule-1" or selection? = "matching-rule-2" or
    selection? = "matching-rule-3" or selection? = "matching-rule-4" [ sort-circle ]            ;; sort in a circle to clearly see the groups
end

to switch-groups                        ;; switch groups after X rounds
  ask students [ set input-leave-stay ifelse-value leave-stay = "initial"
    [ initial-threshold ][ ifelse-value leave-stay = "conditional-cooperator" [ 1 - initial-threshold ] [ 0.5 ] ] ]
  foreach range num-of-groups [ ff -> ask students with [ label = ff ][ if input-leave-stay > group-reputation [                                   ;; leave or stay implementation
    set my-group ""
    set label "" ] ] ]
  if any? students with [ label != "" ] = true [
    if ( random-float 1 ) < noise [                                                                                                                ;; noise in leave-stay rule;
      ifelse ( count students with [ label != "" ] ) < ( round ( count students * noise ) )                                                        ;; if noise = true ask proportion of random stayers to leave
      [ ask students with [ label != "" ] [                                                                                                        ;; only stayers
          set my-group ""                                                                                                                          ;; students may wrongfully decide to leave.
          set label "" ] ]
      [ ask n-of ( round ( count students * noise ) ) students with [ label != "" ] [                                                              ;; A number of agents (based on the chances of noise) who are satisfied,
          set my-group ""                                                                                                                          ;; might wrongfully decide to leave.
          set label "" ] ] ] ]
  count-group-members                                                                                                                              ;; check how many students there remain in each group
  ask students with [ label = "" ] [                                                                                                               ;; students without label are put in the pool group
    set pool? true
    set threshold initial-threshold ]                                                                                                              ;; agents start off with their initial threshold in the next round when pooled
  ifelse selection? = "matching-rule-5" or selection? = "matching-rule-6" [ SN-meritocratic-matching ] [ meritocratic-matching ]                   ;; matching algorithms
  count-group-members                                                                                                                              ;; check how many students there are in each group
  if not any? students with [my-group = "" and number-of-group-members !=  num-of-agents-per-group] [ ask students [ set label my-group  ] ]       ;; set label for all the group one resides in
end

to count-group-members                  ;; count how many members have the same label as the group label
  foreach range num-of-groups [ ff -> ask groups with [ label = ff ] [ set count-members ( count students with [ label = ff ] ) ] ]                ;; how many students in the group (group-own)
  foreach range num-of-groups [ ff -> ask students with [ label = ff ] [ set number-of-group-members ( count students with [ label = ff ] ) ] ]    ;; calculate student-own calculation of group mates
end

to meritocratic-matching                ;; matching for rules 1 to 4
  let unsatisfied-students students with [ my-group = "" ]                                                                                         ;; students who left the group in a population
  let input 0                                                                                                                                      ;; selection of the group
  while [ any? unsatisfied-students ] [                                                                                                            ;; loop until all are grouped
    let selected-group item input sorted-groups                                                                                                    ;; select first group
    let n-students-group [ count-members ] of selected-group                                                                                       ;; how many members in that group
    let counter ( num-of-agents-per-group - n-students-group )                                                                                     ;; how many open spots in that group
    ask max-n-of counter unsatisfied-students                                                                                                      ;; based on empty slots, fill all empty slots in the group
        [ ifelse-value selection? = "matching-rule-1" or selection? = "matching-rule-2" [ coop-rate-total ]                                        ;; full information of all prior individual cooperation actions
          [ ifelse-value selection? = "matching-rule-3" [ coop-rate ] [ group-reputation ] ] ]                                                     ;; only use information of the last X rounds (ind = coop-rate; group-rep = group)
    [ set my-group [ label ] of selected-group ]                                                                                                   ;; sorting based on only group success
    set input ( input + 1 )                                                                                                                        ;; on to the next group
    set unsatisfied-students ( unsatisfied-students with [ my-group = "" ] ) ]                                                                     ;; stop if all students are matched
end

to SN-meritocratic-matching             ;; matching for rules 5 and 6
  let unassigned-friends students with [ my-group = "" ]                                                                                           ;; students who left the group in a population
  ask unassigned-friends [ set input-matching group-reputation ]                                                                                   ;; set group-reputation as input for matching here, we add SN info later on
  let input 0                                                                                                                                      ;; selection of the group
  nw:with-context students socialties [ while [ any? unassigned-friends ] [                                                                        ;; loop until all are grouped
    let selected-group item input sorted-groups                                                                                                    ;; select one group (first option in the preference list of groups)
    let n-students-group [ count-members ] of selected-group                                                                                       ;; how many members in that group
    let counter ( num-of-agents-per-group - n-students-group )                                                                                     ;; how many open spots in that group
    ifelse ( counter < num-of-agents-per-group) and ( counter > 0 )                                                                                ;; two options: (if) = if there are still students in the group, (else) empty group
    ;;IF
    [ let tt turtle-set ( [ ( nw:turtles-in-radius range-SN ) with [ my-group = "" ] ] of students with [ label =  [ label ] of selected-group ] ) ;; find friends and friends-of-friends who are available to group-up with
      ask tt [ set input-matching cooperativeness-score-all ]                                                                                      ;; ask available friends to update their input matching parameter
      ask max-n-of counter unassigned-friends [ input-matching ] [ set my-group [ label ] of selected-group ]                                      ;; based on empty slots, fill all empty slots in the group
    ]
    ;;ELSE
    [ ask max-one-of unassigned-friends [ cooperativeness-score-all ] [                                                                            ;; if the group is empty, ask the most reputable student to form a group
        let pt [ ( nw:turtles-in-radius range-SN ) with [ my-group = "" ] ] of self                                                                ;; find friends and friends-of-friends with a prosocial reputation
        ask pt [ set input-matching cooperativeness-score-all ]                                                                                    ;; ask available friends to update their input matching parameter
        ask max-n-of counter unassigned-friends [ input-matching ] [ set my-group [ label ] of selected-group ] ] ]                                ;; based on empty slots, fill all empty slots in the group
    set input ( input + 1 )                                                                                                                        ;; on to the next group
    set unassigned-friends ( unassigned-friends with [ my-group = "" ] )                                                                           ;; stop if all students are matched
  ]
]
end

;---------------------------written by Carlos de Matos Fernandes---------------------------c.a.de.matos.fernandes@rug.nl--------------------------------------------------------
@#$#@#$#@
GRAPHICS-WINDOW
680
35
1173
529
-1
-1
14.7
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
ticks
30.0

BUTTON
510
35
670
180
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
510
185
670
290
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SLIDER
5
65
160
98
num-of-groups
num-of-groups
0
20
20.0
5
1
NIL
HORIZONTAL

INPUTBOX
5
235
160
295
max-number-of-ticks
400.0
1
0
Number

SLIDER
165
65
320
98
num-of-agents-per-group
num-of-agents-per-group
4
8
8.0
1
1
NIL
HORIZONTAL

BUTTON
510
360
670
393
NIL
initial-setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
510
295
670
328
go once
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

SLIDER
5
180
160
213
L
L
0
1
0.5
0.1
1
NIL
HORIZONTAL

SLIDER
165
125
320
158
M
M
1
10
5.0
1
1
NIL
HORIZONTAL

MONITOR
1205
260
1350
305
cooperation rate
(count students with [cooperate? = 1]/ count students)
2
1
11

INPUTBOX
5
520
55
580
k
5.0
1
0
Number

INPUTBOX
60
520
110
580
y
8.0
1
0
Number

TEXTBOX
15
490
115
520
Random spatial graph parameters
11
0.0
1

INPUTBOX
5
315
55
375
COST
3.0
1
0
Number

INPUTBOX
60
315
120
375
BENEFIT
4.5
1
0
Number

INPUTBOX
125
315
230
375
BENEFIT-OF-ALL-D
-0.5
1
0
Number

TEXTBOX
960
535
1190
610
grey \t\t= proself threshold\nred \t\t= prosocial threshold + defect\nlight red \t= proself threshold + defect\nred link = one or both defected in 2-person PD
11
0.0
1

SLIDER
5
125
160
158
%-prosocials
%-prosocials
0.2
0.8
0.4
0.2
1
NIL
HORIZONTAL

INPUTBOX
335
65
435
125
initial-proself
0.7
1
0
Number

INPUTBOX
335
130
435
190
initial-prosocial
0.3
1
0
Number

CHOOSER
245
325
425
370
selection?
selection?
"matching-rule-1" "matching-rule-2" "matching-rule-3" "matching-rule-4" "matching-rule-5" "matching-rule-6"
5

INPUTBOX
165
235
320
295
count-ticks-for-selection
100.0
1
0
Number

INPUTBOX
330
235
460
295
length-last-rounds-history
10.0
1
0
Number

TEXTBOX
690
535
940
650
light grey \t= prosocial threshold \ngreen \t\t= prosocial threshold + cooperate\nlight green \t= proself threshold + cooperate\nwhite link = both cooperated in 2-person PD\ncyan link = group tie
11
0.0
1

BUTTON
590
425
665
458
only-group
ask socialties [ hide-link ]\nask studyties [ show-link ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
510
460
665
493
show-both-SN-group
ask studyties [ show-link ]\nask socialties [ show-link ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
510
425
585
458
only-network
ask studyties [ hide-link ]\nask socialties [ show-link ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
515
345
665
366
Reset parameter settings
12
0.0
1

TEXTBOX
10
50
85
68
Group size
12
0.0
1

TEXTBOX
170
50
320
68
Number of agents
12
0.0
1

TEXTBOX
10
110
160
128
Percentage prosocials
12
0.0
1

TEXTBOX
10
165
110
183
Learning
12
0.0
1

TEXTBOX
170
110
235
128
Slope
12
0.0
1

TEXTBOX
10
220
120
238
End after ? ticks
12
0.0
1

TEXTBOX
170
220
320
238
Selection after ? ticks
12
0.0
1

TEXTBOX
250
305
420
325
Matching rules
14
0.0
1

TEXTBOX
10
300
110
320
Payoffs
12
0.0
1

TEXTBOX
340
45
490
63
Initial threshold
12
0.0
1

BUTTON
510
515
665
548
sort in groups
sort-circle\nask socialties [ set thickness 0.000001]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
515
405
675
425
Visualization options
12
0.0
1

PLOT
1205
360
1620
530
cooperation rates in dyadic PD
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"overall cooperation" 1.0 0 -4539718 true "" "plot mean [private-c?] of students"
"overall defection" 1.0 0 -1069655 true "" "plot (count students with [private-c? = 0] / count students)"
"prosocials C" 1.0 0 -16777216 true "" "plot mean [private-c?] of students with [initial-threshold = initial-prosocial]"
"proselfs C" 1.0 0 -2674135 true "" "plot mean [private-c?] of students with [initial-threshold = initial-proself]"

SWITCH
165
415
320
448
behavioral-homophily?
behavioral-homophily?
1
1
-1000

SLIDER
165
180
320
213
noise
noise
0
0.5
0.01
0.01
1
NIL
HORIZONTAL

TEXTBOX
170
450
365
480
Behavioral homophily allows same-type agents to cooperate (2-PDs) more easily
11
0.0
1

PLOT
1205
35
1680
255
cooperation rates and thresholds per type in the group ( n-person PD)
NIL
NIL
0.0
1.0
0.0
1.0
true
true
"" ""
PENS
"prosocials threshold" 1.0 2 -16777216 true "" "plot mean [threshold] of students with [initial-threshold = initial-prosocial]"
"proselfs threshold" 1.0 2 -2674135 true "" "plot mean [threshold] of students with [initial-threshold = initial-proself]"
"prosocials coop-rate" 1.0 0 -7500403 true "" "plot mean [cooperate?] of students with [initial-threshold = initial-prosocial]"
"proselfs coop-rate" 1.0 0 -955883 true "" "plot mean [cooperate?] of students with [initial-threshold = initial-proself]"
"level of cooperation" 1.0 0 -13840069 true "" "plot mean [cooperate?] of students"

SWITCH
5
415
160
448
structural-homophily?
structural-homophily?
0
1
-1000

TEXTBOX
10
450
160
480
Structural homophily sorts prosocials together on the grid
11
0.0
1

MONITOR
1205
580
1385
625
Social network: MS odds-ratio
moody-segregation
3
1
11

INPUTBOX
220
520
310
580
range-SN
2.0
1
0
Number

TEXTBOX
225
490
315
525
Social network information range
11
0.0
1

TEXTBOX
335
220
485
260
Memory of agents 
12
0.0
1

MONITOR
1360
260
1480
305
% prosocials C
(count students with [cooperate? = 1 and initial-threshold = initial-prosocial]) / count students with [initial-threshold = initial-prosocial] * 100
2
1
11

MONITOR
1490
260
1610
305
% proselfs C
(count students with [cooperate? = 1 and initial-threshold = initial-proself]) / count students with [initial-threshold = initial-proself] * 100
2
1
11

TEXTBOX
245
370
490
400
Note: The chosen matching rule adjusts features automatically (e.g. pre-game or homophily)
11
0.0
1

BUTTON
510
590
575
623
visual SN
ifelse selection? = \"matching-rule-5\" or selection? = \"matching-rule-6\" [ask studyties [hide-link]][ask studyties [show-link]] \nask patches [set pcolor white]\nask socialties [ set color grey + 2 set thickness 0.2]\nask students [ set shape (\"circle\") set size 1.2]\nask students with [initial-threshold = initial-prosocial][set color black ]\nask students with [initial-threshold = initial-proself][set color grey]\nask students [set label \"\"]\nask groups [hide-turtle]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
1395
580
1597
625
Group: MS prosociality segregation
prosociality-segregation
2
1
11

INPUTBOX
120
520
195
580
r
0.05
1
0
Number

TEXTBOX
1205
10
1635
35
Model output in the group context (N-person PD)
18
0.0
1

TEXTBOX
1205
330
1650
355
Model output in the network context (2-person PD)
18
0.0
1

TEXTBOX
1205
550
1760
591
Gross-segregation index for the social network and groups
18
0.0
1

TEXTBOX
685
10
835
31
World
18
0.0
1

TEXTBOX
510
10
660
35
Engine
18
0.0
1

TEXTBOX
5
10
190
35
Input for the model
18
0.0
1

TEXTBOX
1690
15
1840
33
Seed of the run
12
0.0
1

TEXTBOX
170
165
320
183
Noise in leave-stay
12
0.0
1

TEXTBOX
10
395
160
420
Social network input
14
0.0
1

TEXTBOX
120
490
215
525
Chance of dyad selection
11
0.0
1

TEXTBOX
515
560
635
595
Button 'visual SN' is for paper visualisation
11
0.0
1

TEXTBOX
585
590
670
616
grey = proself\nblack = prosocial
11
0.0
1

MONITOR
1690
35
1775
80
NIL
my-seed
17
1
11

TEXTBOX
505
500
680
526
useful for matching rule 5 and 6 
11
0.0
1

CHOOSER
370
450
470
495
leave-stay
leave-stay
"initial" "conditional-cooperator" "50-percent"
0

TEXTBOX
370
415
495
445
Variations on the leave-stay procedure
11
0.0
1

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.2.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="social-network-single-run" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="propositions-prosociality segregation" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="MS-moody-social-network" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1"/>
    <metric>moody-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity-general" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.1"/>
      <value value="0.3"/>
      <value value="0.5"/>
      <value value="0.7"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="1"/>
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity-noise-leavestay" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0"/>
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity-r" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.01"/>
      <value value="0.05"/>
      <value value="0.25"/>
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="single-run-model-section" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity-input-leavestay" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
      <value value="&quot;conditional-cooperator&quot;"/>
      <value value="&quot;50-percent&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="sensitivity-BH" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>my-seed</metric>
    <metric>mean [cooperate?] of students</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [cooperate?] of students with [initial-threshold = initial-proself]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-prosocial]</metric>
    <metric>mean [private-c?] of students with [initial-threshold = initial-proself]</metric>
    <metric>prosociality-segregation</metric>
    <enumeratedValueSet variable="selection?">
      <value value="&quot;matching-rule-1&quot;"/>
      <value value="&quot;matching-rule-2&quot;"/>
      <value value="&quot;matching-rule-3&quot;"/>
      <value value="&quot;matching-rule-4&quot;"/>
      <value value="&quot;matching-rule-5&quot;"/>
      <value value="&quot;matching-rule-6&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="behavioral-homophily?">
      <value value="true"/>
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="%-prosocials">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="L">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="M">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-agents-per-group">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="num-of-groups">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-number-of-ticks">
      <value value="400"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="count-ticks-for-selection">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="COST">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BENEFIT-OF-ALL-D">
      <value value="-0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-proself">
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-prosocial">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r">
      <value value="0.05"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="y">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="length-last-rounds-history">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="range-SN">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="0.01"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="leave-stay">
      <value value="&quot;initial&quot;"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

undirected
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 45 150 240
@#$#@#$#@
1
@#$#@#$#@
